@@ -2,6 +2,11 @@ from __future__ import unicode_literals
 
 import os
 
+try:
+    from shlex import quote
+except ImportError:
+    from pipes import quote
+
 from django.contrib.staticfiles import finders
 from django.core.files.base import ContentFile
 from django.utils.encoding import smart_str, smart_bytes
@@ -22,9 +27,6 @@ class Compiler(object):
         return [to_class(compiler) for compiler in settings.PIPELINE_COMPILERS]
 
     def compile(self, paths, force=False):
-        import multiprocessing
-        from concurrent import futures
-
         def _compile(input_path):
             for compiler in self.compilers:
                 compiler = compiler(verbose=self.verbose, storage=self.storage)
@@ -34,7 +36,8 @@ class Compiler(object):
                     outfile = self.output_path(infile, compiler.output_extension)
                     outdated = compiler.is_outdated(input_path, output_path)
                     try:
-                        compiler.compile_file(infile, outfile, outdated=outdated, force=force)
+                        compiler.compile_file(quote(infile), quote(outfile),
+                            outdated=outdated, force=force)
                     except CompilerError:
                         if not self.storage.exists(output_path) or settings.DEBUG:
                             raise
@@ -42,8 +45,14 @@ class Compiler(object):
             else:
                 return input_path
 
-        with futures.ThreadPoolExecutor(max_workers=multiprocessing.cpu_count()) as executor:
-            return list(executor.map(_compile, paths))
+        try:
+            import multiprocessing
+            from concurrent import futures
+        except ImportError:
+            return list(map(_compile, paths))
+        else:
+            with futures.ThreadPoolExecutor(max_workers=multiprocessing.cpu_count()) as executor:
+                return list(executor.map(_compile, paths))
 
     def output_path(self, path, extension):
         path = os.path.splitext(path)
